@@ -16,11 +16,9 @@ public:
 
     void updateUi();
 
-signals:
-    void fmBoostChanged(int);
-
-private slots:
-    void on_boostCheckBox_stateChanged(int state);
+    bool getBoostCheckBoxState();
+    uint getPreset1SpinBoxValue();
+    uint getPreset2SpinBoxValue();
 
 private:
     FFMWidget * mWidget;
