@@ -75,7 +75,8 @@ FFMWidget::FFMWidget()
     connect(&mLeftButton, SIGNAL(clicked()), this, SLOT(decrementFrequency()));
     connect(&mMiddleButton, SIGNAL(clicked()), this, SLOT(switchFMTransmitter()));
     connect(&mRightButton, SIGNAL(clicked()), this, SLOT(incrementFrequency()));
-    connect(&mTopButton, SIGNAL(clicked()), this, SLOT(switchBTRadio()));
+    connect(&mTopButton, SIGNAL(btClicked()), this, SLOT(switchBTRadio()));
+    connect(&mTopButton, SIGNAL(tmClicked()), this, SLOT(switchPreset()));
 
     mSystemBus.connect("com.nokia.FMTx", "/com/nokia/fmtx/default", "com.nokia.FMTx.Device", "Changed", this, SLOT(fmPropertyChanged()));
     mSystemBus.connect("org.bluez", path.path(), "org.bluez.Adapter", "PropertyChanged", this, SLOT(btPropertyChanged(QString, QDBusVariant)));
@@ -92,6 +93,8 @@ FFMWidget::FFMWidget()
 
     mFMBoostInstalled = QFile::exists("/sbin/fm-boost");
     mFMBoostActivated = mSettings.value("FMBoostActivated", false).toBool();
+    mPreset1 = mSettings.value("Preset1", mFreqMin).toUInt();
+    mPreset2 = mSettings.value("Preset2", mFreqMin).toUInt();
 }
 
 FFMWidget::~FFMWidget()
@@ -112,14 +115,20 @@ void FFMWidget::showSettingsDialog()
     if (!mSettingsDlg)
     {
         mSettingsDlg = new FFMSettingsDialog(this);
-        connect(mSettingsDlg, SIGNAL(fmBoostChanged(int)), this, SLOT(fmBoostChanged(int)));
     }
 
     // could have changed in the meantime
     mFMBoostInstalled = QFile::exists("/sbin/fm-boost");
 
     mSettingsDlg->updateUi();
-    mSettingsDlg->show();
+    mSettingsDlg->exec();
+
+    mFMBoostActivated = mSettingsDlg->getBoostCheckBoxState();
+    mSettings.setValue("FMBoostActivated", mFMBoostActivated);
+    mPreset1 = mSettingsDlg->getPreset1SpinBoxValue();
+    mSettings.setValue("Preset1", mPreset1);
+    mPreset2 = mSettingsDlg->getPreset2SpinBoxValue();
+    mSettings.setValue("Preset2", mPreset2);
 }
 
 void FFMWidget::incrementFrequency()
@@ -166,6 +175,18 @@ void FFMWidget::switchBTRadio()
     }
 }
 
+void FFMWidget::switchPreset()
+{
+    if (mFreqCurrent == mPreset1)
+    {
+        mFMIface->call("Set", "com.nokia.FMTx.Device", "frequency", QVariant::fromValue(QDBusVariant(mPreset2)));
+    }
+    else
+    {
+        mFMIface->call("Set", "com.nokia.FMTx.Device", "frequency", QVariant::fromValue(QDBusVariant(mPreset1)));
+    }
+}
+
 void FFMWidget::fmPropertyChanged()
 {
     QDBusVariant dbv = qvariant_cast<QDBusVariant>(mFMIface->call("Get", "com.nokia.FMTx.Device", "state").arguments().first());
@@ -207,9 +228,3 @@ void FFMWidget::btPropertyChanged(QString property, QDBusVariant value)
     }
 }
 
-void FFMWidget::fmBoostChanged(int state)
-{
-    mFMBoostActivated = state == Qt::Checked ? true : false;
-    mSettings.setValue("FMBoostActivated", mFMBoostActivated);
-}
-
