@@ -42,6 +42,10 @@ public:
 
     inline bool isFMBoostInstalled();
     inline bool isFMBoostActivated();
+    inline uint getMinFrequency();
+    inline uint getMaxFrequency();
+    inline uint getPreset1();
+    inline uint getPreset2();
 
 public slots:
     void showSettingsDialog();
@@ -49,16 +53,16 @@ public slots:
     void decrementFrequency();
     void switchFMTransmitter();
     void switchBTRadio();
+    void switchPreset();
 
     void fmPropertyChanged();
     void btPropertyChanged(QString property, QDBusVariant value);
 
-    void fmBoostChanged(int state);
-
 protected:
     bool mBtOn, mTmOn;
     bool mFMBoostInstalled, mFMBoostActivated;
     uint mFreqStep, mFreqMin, mFreqMax, mFreqCurrent;
+    uint mPreset1, mPreset2;
 
     FFMSimpleButton mLeftButton, mRightButton;
     FFMToggleButton mMiddleButton;
@@ -82,4 +86,24 @@ inline bool FFMWidget::isFMBoostActivated()
     return mFMBoostActivated;
 }
 
+inline uint FFMWidget::getMinFrequency()
+{
+    return mFreqMin;
+}
+
+inline uint FFMWidget::getMaxFrequency()
+{
+    return mFreqMax;
+}
+
+inline uint FFMWidget::getPreset1()
+{
+    return mPreset1;
+}
+
+inline uint FFMWidget::getPreset2()
+{
+    return mPreset2;
+}
+
 #endif
